from typing import Any

from src.crud.crud import get_prompt
from src.database import sync_db_helper

# ROLE = """
# Вы являетесь опытным маркетологом в компании,
#  которая разрабатывает программное обеспечение любой сложности на основе аутсорсинга.
#  Компания специализируется на:
# ✓ Backend: Python, ...
# ✓ Frontend: React, JS, CSS
# ✓ Мобильная разработка: Flutter, iOS/Android (Kotlin/Swift)
# ✓ Data Science & AI: машинное обучение, компьютерное зрение
# ✓ Кибербезопасность
#
# Ваша задача — анализировать переписку и находить потенциальных клиентов, которым нужна разработка ПО.
# """

ANALYTIC_PROMPT = """
Ты получаешь json с такими полями:
{
  "chats": [
    {
      "slice_id": "UUID4",
      "messages": [
        {
          "user_id": integer,
          "message_id": integer,
          "text": string,
          "date": "datetime"
        }
      ]
    }
  ]
}

Анализируй каждый чат отдельно. Ответ должен быть ТОЛЬКО в JSON формате, без каких-либо пояснений или форматирования.

Пример правильного ответа:
{
  "success": [
    {
      "user_id": 123,
      "slice_id": "550e8400-e29b-41d4-a716-446655440000",
      "reason": "Упоминание разработки мобильного приложения с указанием технологий"
    }
  ]
}

Если нет четких признаков или есть сомнения, верни:
{"success": null}

Правила анализа:
%s
"""



def create_base_message() -> list[dict[str, Any]]:
    with sync_db_helper.session_factory() as session:
        prompt = get_prompt(session)

    return [
        {
            "role": "user",
            "parts": [
                {"text": prompt.role},
                {"text": ANALYTIC_PROMPT % prompt.prompt},
            ]
        },
    ]
